# Import the SketchUp API.
require "sketchup.rb"

# Define a class for the extension.
class RandomColorPaint
  # This is a constant for the maximum value of a color component (256 in this case).
  MAX_COLOR_VALUE = 256

  # This is a custom method that will be called when the extension is activated.
  def activate
    # Get the current model and the selection set.
    model = Sketchup.active_model
    selection = model.selection

    # Use the #grep method to find only the faces in the selection.
    faces = selection.grep(Sketchup::Face)

    # Select only the faces that are visible.
    visible_faces = faces.select { |face| face.visible? }

    # Loop over the visible faces and paint them with random colors.
    visible_faces.each do |face|
      # Generate a random color and set it as the material for the face.
      color = generate_random_color
      face.material = color
    end
  end

  # This method generates a random color and returns it.
  def generate_random_color
    r = rand(MAX_COLOR_VALUE)
    g = rand(MAX_COLOR_VALUE)
    b = rand(MAX_COLOR_VALUE)
    Sketchup::Color.new(r, g, b)
  end
end

# Create a new instance of the RandomColorPaint class.
paint_tool = RandomColorPaint.new

# Get a reference to the Extensions menu.
extensions_menu = UI.menu("Extensions")

# Add a new menu item for your extension to the Extensions menu.
extensions_menu.add_item("Paint with random colors") do
  # When the menu item is clicked, activate your extension.
  paint_tool.activate
end
